function PR = empPsi(massflow,rotspeed)

% Function output: -pressure ratio p02/p01
%                  -polynomial coeff and coefficiants
% Input: mass flow and rotational speed in 
%            rev per min

w = massflow;
N = rotspeed;

% psi(w,N) = c0(N) + c1(N)w + c2(N)w^2 + c3(N)w^3
% ci(N) = c0i + c1i*N + c2i*N^2 + c3i*N^3, i = 0...4

%% Load coefficients from file
load('datafile0103coeffs.mat'); % datafile containing the coefficients
% structure of coefficients file:
% [c0(4). .. c0(1)  c1(4)... c1(1).... c3(4). .. c3(1) ]
%c0 = coeff(1:4); c1 = coeff(5:8); c2 = coeff(9:12); c3 = coeff(13:16);

if all(w == 0)
    PR = 0;
end
if all(N == 0)
    PR = 0;
elseif N < 0 
    disp('Error, rot. speed out of bounds.');
end
if numel(w)>1 && numel(N)>1
    a = length(w);

    PR = zeros(1,a);
    for i = 1:a
        c0N =  c0(4) + c0(3)*N(i) + c0(2)*N(i)^2 + c0(1)*N(i)^3;
        c1N =  c1(4) + c1(3)*N(i) + c1(2)*N(i)^2 + c1(1)*N(i)^3;
        c2N =  c2(4) + c2(3)*N(i) + c2(2)*N(i)^2 + c2(1)*N(i)^3;
        c3N =  c3(4) + c3(3)*N(i) + c3(2)*N(i)^2 + c3(1)*N(i)^3;

        PR(i) = c0N + c1N*w(i) + c2N*w(i)^2 + c3N*w(i)^3; % returns v with
                                                       % length of w
    end
 
elseif numel(w)>1
    a = length(w);
    PR = zeros(1,a);
    c0N =  c0(4) + c0(3)*N + c0(2)*N^2 + c0(1)*N^3;
    c1N =  c1(4) + c1(3)*N + c1(2)*N^2 + c1(1)*N^3;
    c2N =  c2(4) + c2(3)*N + c2(2)*N^2 + c2(1)*N^3;
    c3N =  c3(4) + c3(3)*N + c3(2)*N^2 + c3(1)*N^3;
    
    for i = 1:a
        PR(i) = c0N + c1N*w(i) + c2N*w(i)^2 + c3N*w(i)^3; % returns v with
                                                       % length of w
    end
elseif numel(N)>1
    b = length(N);
    PR = zeros(1,b);
     for i = 1:b
        c0N =  c0(4) + c0(3)*N(i) + c0(2)*N(i)^2 + c0(1)*N(i)^3;
        c1N =  c1(4) + c1(3)*N(i) + c1(2)*N(i)^2 + c1(1)*N(i)^3;
        c2N =  c2(4) + c2(3)*N(i) + c2(2)*N(i)^2 + c2(1)*N(i)^3;
        c3N =  c3(4) + c3(3)*N(i) + c3(2)*N(i)^2 + c3(1)*N(i)^3;
        PR(i) = c0N + c1N*w + c2N*w^2 + c3N*w^3;
    end
else
    c0N =  c0(4) + c0(3)*N + c0(2)*N^2 + c0(1)*N^3;
    c1N =  c1(4) + c1(3)*N + c1(2)*N^2 + c1(1)*N^3;
    c2N =  c2(4) + c2(3)*N + c2(2)*N^2 + c2(1)*N^3;
    c3N =  c3(4) + c3(3)*N + c3(2)*N^2 + c3(1)*N^3;

    PR = c0N + c1N*w + c2N*w^2 + c3N*w^3;   % returns pressure ratio
                                            % p2/p1
end
