%% Polyfit function of compressor characterstic.
% Create coeff. for each speed line
% Curve fit to polynomial functions
% 27.01.2017, N.T.
% REV: 6/2, 28/2, 1/3
clear all; close all; clc;

%% DATA:
%load('datafile0602.mat'); % load established data file
%load('datafile2802.mat'); % REV 28/2, new zero mass flow values
load('datafile0103.mat'); % REV 1/3, new PR for negative mass flow tuned

% structure of datafile:
%            
%          sp17 - vector with speed line data, bolk length  = n
%               [0w 0psi
%               [1w 1psi...
%               [7iw 7i psi] % last two rows is tuned data 
%          spd - vector with speed line data, zero data, bolk length = m
%               [0w 0psi
%               [1w 1psi...
%               [7iw 7i psi] % last two rows is tuned data
%          spdf - ...., zero and negative data, bolk length = f
%               [0w 0psi
%               [1w 1psi...
%               [6iw 6i psi] % last two rows is tuned data
%               [7iw 7i psi %
%          map815 - vector with map data, surge choke efficiency, length nm
%               [08w 08psi, surge ( small line)
%               [09w 09psi... choke (65 perc.)
%               [10w  10psi   surge (66 line)
%               [15w 15psi]      70, 75, 76, 77 and 78 (15)

polyfit_speedlines; % Call script to create polynomial coeff.
% structure of data from polyfit_speedlines
%
%       pxx - polynomial coeff for each speed line 75-195
%       pxxi - same as above, just for tuned speed lines 175 and 195k rpm
%       fxxx - function value of polynomial pxx in x
%       exxx - error table with deviation from original datapoint
%

%% Determine coefficants given by rotational speed, N

% p = a1w^3 + a2w^2 + a3w + a4 . oposite order
M = [p75; p95; p115; p135; p155; p175i; p195i]; % all coeff in M, y
N = [75000 95000 115000 135000 155000 175000 195000]'; % speed lines, x

% determine the poly. coeff for the pressure ratio poly.
% MN = [rpm 75..195 M(p(4)... p(3)..p(1) ]
% polyfit, p(4)w^3 + p(3)w^2 + p(2)w + p(1)

ca0 = [N M(1:7,4)]; ca1 =[N M(1:7,3)]; ca2 = [N M(1:7,2)];
ca3 = [N M(1:7,1)]; % coefficiants given by rpm

%% param
o = 3; % order of polynomial
%omega = N/2pi
%N = N*(1/(2*pi*60)); % get axis in /s, omega

%% Calling polyfit function
xc0 = ca0(:,1); yc0 = ca0(:,2); % declare parts of coeff
[c0,y_c0,e_c0] = polyFitCreate(ca0,o); % create poly, order - o
xc1 = ca1(:,1); yc1 = ca1(:,2);
[c1,y_c1,e_c1] = polyFitCreate(ca1,o); % y_ci is the function values
xc2 = ca2(:,1); yc2 = ca2(:,2);
[c2,y_c2,e_c2] = polyFitCreate(ca2,o);
xc3 = ca3(:,1); yc3 = ca3(:,2);
[c3,y_c3,e_c3] = polyFitCreate(ca3,o);


%% END USER INPUT
prompt = 'Save file with data (coefficiants)? Y/N: ';
str = input(prompt,'s');
if isempty(str)
    str = 'N';
end
if str == 'Y' || str == 'y'
    prompt = 'filename (filename.mat): ';
    str2 = input(prompt,'s');
    disp('Saving data to file...')
    % save coeff in one file
    filename = str2;
    save(filename,'c0','c1','c2','c3');
end
disp('polyfit_coeffs END')