%% Create polynomials for each speed line
% Curve fit to polynomial functions
% 10.01.2017, Nj?l Tengesdal
% REV: 27/1, 3/2, 6/2
clear all; close all; clc;
%% DATA:
%load('datafile0602.mat'); % load established data file
%load('datafile2802.mat'); % REV 3/1-17, new dataset changed zero values
load('datafile0103.mat'); % --- new point for negative mass flow 195k

% structure of datafile:
%            
%          sp17 - vector with speed line data, bolk length  = n
%               [0w 0psi
%               [1w 1psi...
%               [7iw 7i psi] % last two rows is tuned data 
%          spd - vector with speed line data, zero data, bolk length = m
%               [0w 0psi
%               [1w 1psi...
%               [7iw 7i psi] % last two rows is tuned data
%          spdf - ...., zero and negative data, bolk length = f
%               [0w 0psi
%               [1w 1psi...
%               [6iw 6i psi] % last two rows is tuned data
%               [7iw 7i psi %
%          map815 - vector with map data, surge choke efficiency, length nm
%               [08w 08psi, surge ( small line)
%               [09w 09psi... choke (65 perc.)
%               [10w  10psi   surge (66 line)
%               [15w 15psi]      70, 75, 76, 77 and 78 (15)

%% Fit params, speed lines
o = 3; %order of polynom

%% SPEED LINES
% d001 - d007, p - coeff. vector, f - curve of poly in x

x1 = spdf(1:f,1); y1 = spdf(1:f,2);
[p75,f75,e75] = polyFitCreate([x1 y1],o); % 75k RPM

x2 = spdf(f*(2-1)+1:f*2,1); y2 = spdf(f*(2-1)+1:f*2,2);
[p95,f95,e95] = polyFitCreate([x2 y2],o); % speed lines for 95k RPM

x3 = spdf(f*(3-1)+1:f*3,1); y3 = spdf(f*(3-1)+1:f*3,2);
[p115,f115,e115] = polyFitCreate([x3 y3],o); % speed lines for 115k RPM

x4 = spdf(f*(4-1)+1:f*4,1); y4 = spdf(f*(4-1)+1:f*4,2);
[p135,f135,e135] = polyFitCreate([x4 y4],o); % speed lines for 135k RPM

x5 = spdf(f*(5-1)+1:f*5,1); y5 = spdf(f*(5-1)+1:f*5,2);
[p155,f155,e155] = polyFitCreate([x5 y5],o); % speed lines for 155k RPM

x6 = spdf(f*(6-1)+1:f*6,1); y6 = spdf(f*(6-1)+1:f*6,2);
[p175,f175,e175] = polyFitCreate([x6 y6],o); % speed lines for 175k RPM

x7 = spdf(f*(7-1)+1:f*7,1); y7 = spdf(f*(7-1)+1:f*7,2);
[p195,f195,e195] = polyFitCreate([x7 y7],o); % speed lines for 195k RPM

x6i = spdf(f*(8-1)+1:f*8,1); y6i = spdf(f*(8-1)+1:f*8,2);
[p175i,f175i,e175i] = polyFitCreate([x6i y6i],o); % speed lines for 175k RPM

x7i = spdf(f*(9-1)+1:f*9,1); y7i = spdf(f*(9-1)+1:f*9,2);
[p195i,f195i,e195i] = polyFitCreate([x7i y7i],o); % speed lines for 195k RPM


%% SURGE LINE
% d008 and d010 (60%)
x8 = map815(1:nm,1); y8 = map815(1:nm,2); % Small fraction of surge line
x10 = map815(nm*2+1:nm*3,1); y10 = map815(nm*2+1:nm*3,2); % larger part

[pS1,fS1,eS1] = polyFitCreate([x8 y8], 3);
[pS2,fS2,eS2] = polyFitCreate([x10 y10], 3);

%% CHOKE LINE (60% efficiency)
% d009
x9 = map815(nm+1:nm*2,1); y9 = map815(nm+1:nm*2, 2);
[pCh,fCh,eCh] = polyFitCreate([x9 y9], 3);

%% ERROR CHECK
% 155k line
nx5 = spdf(f*(5-1)+1:f*5,1); ny5 = spdf(f*(5-1)+1:f*5,2);

[p1nd,f1nd,eTbl1nd] = polyFitCreate([nx5 ny5],1);
[p3rd,f3rd,eTbl3rd] = polyFitCreate([nx5 ny5],3);
[p4th,f4th,eTbl4th] = polyFitCreate([nx5 ny5],4);
fst = abs(eTbl1nd.FitError);
third = abs(eTbl3rd.FitError);
fourth = abs(eTbl4th.FitError);
compare155k = table(nx5,ny5,fst,third,fourth,...
    'VariableNames',{'w','PR','errFirst','errThird','errFourth'})
% error percentage
er1 = 1/length(f1nd)*sum(abs(f1nd-y5))
er2 = 1/length(f3rd)*sum(abs(f3rd-y5))
er3 = 1/length(f4th)*sum(abs(f4th-y5))
erroo = table(er1,er2,er3,...
    'VariableNames',{'Error1','Error3','Error4'})
disp('polyfit_speedlines END')
%% END USER INPUT

% prompt = 'Save file with polynomial coefficients? Y/N: ';
% str = input(prompt,'s');
% if isempty(str)
%     str = 'N';
% end
% if str == 'Y' || str == 'y'
%     prompt = 'filename (filename.mat): ';
%     str2 = input(prompt,'s');
%     disp('Saving polynomials to file...')
%     % save coeff in one file
%     filename = str2;
%     save(filename,'p75','p95',...
%         'p115','p135','p155','p175','p195');
% end
