function [psi,dhctot,dhc,dhi,dhf,phi] = psiC(massflow,speed,params)
% Pressure ratio function
% assumptions made in Gravdahl 1997, speed surge control in low order cc
% 
% Total specific energy transfer dhctot(w, omega) = dhctot(-w,omega)

% defining parameters 
r1 = params.r1; r2 = params.r2; A1 = params.A1;
rho1 = params.rho1; beta1b = params.beta1b; beta2b = params.beta2b;
kf = params.kf;
cp = params.cp;
kappa = params.kappa;
T = params.T01;
sig = params.sig;
%

omega=speed;
w = massflow;

alph = cot(beta1b)/(rho1*A1*r1);

phi = w./omega * 1/(rho1*A1*r2); % flow coefficient
phicotbeta2b = phi*cot(beta2b);

dhctot = (sig*r2^2*omega.^2*(1 - (cot(beta2b)/(rho1*A1*r2*omega))*w) -...
    0.5*(r1^2)*(omega - alph.*w).^2 - kf*w.^2); % Total enthalpy

%mu = sig(1 - phi*cotbeta2b);

dhc = sig*r2^2*omega.^2*(1 - phicotbeta2b);
%dhc = sig*r2^2*omega.^2*(1 - (w./omega)*(cot(beta2b)/(rho1*A1*r2))); % entalpy
                                        % increase
dhi = 0.5*(r1^2)*(omega - alph.*w).^2; % inducer loss entalphy

dhf = kf*w.^2; %friction loss entalpy

temp = dhc - dhi - dhf;
temp = max(temp,0);

temp = 1 + temp/(cp*T);

temp = temp.^(kappa/(kappa-1)); % p02/p01

if imag(temp) ~= 0
   psi = abs(temp); % absolute value of psi if imaginary numbers
else
    psi = temp;
end
end