function [psi0correct,psi0modsim] = psicZero(N,D1,D2,T01,cp,kappa)
% - Calculating the zero mass flow point for a specific
%   rpm line of a compressor
%   assumptions: - Isentropic conditions, with kappa
%                  specific heat ratio cp/cv
% (see e.g. Egeland and Gravdahl 2002, Chapter 13, p. 496)

% Input:
% D1 impeller inducer diameter
% D2 impeller exducer diameter
% N  rpm, 
% cp specific heat at constant pressure J/kg.K
% T01 inlet temperature at inducer/impeller eye

omega = N*2*pi*1/60; % from RPM to rad/s 2pi*1/60

temp = 1 + (omega.^2)*(D2^2 - D1^2)/(4*cp*T01);

psi0correct = temp.^(kappa/(kappa-1));

psi0modsim = (1 + (pi^2*(N/60)^2)*(D2^2 - D1^2)/(2*cp*T01)).^(kappa/(kappa-1));